@@ -15,8 +15,16 @@ BEGIN {
         swig_device_set => ["function", "void", "any", "string"],
         swig_mount_get => ["function", "string", "any"],
         swig_mount_set => ["function", "void", "any", "string"],
+        swig_crypt_device_get => ["function", "string", "any"],
+        swig_crypt_device_set => ["function", "void", "any", "string"],
         swig_mount_by_get => ["function", "integer", "any"],
         swig_mount_by_set => ["function", "void", "any", "integer"],
+        swig_udevPath_get => ["function", "string", "any"],
+        swig_udevPath_set => ["function", "void", "any", "string"],
+        swig_udevId_get => ["function", "string", "any"],
+        swig_udevId_set => ["function", "void", "any", "string"],
+        swig_usedBy_get => ["function", ["list", "any"], "any"],
+        swig_usedBy_set => ["function", "void", "any", ["list", "any"]],
         swig_usedByType_get => ["function", "integer", "any"],
         swig_usedByType_set => ["function", "void", "any", "integer"],
         swig_usedByDevice_get => ["function", "string", "any"],
@@ -43,6 +51,8 @@ BEGIN {
         swig_crypt_pwd_set => ["function", "void", "any", "string"],
         swig_fs_get => ["function", "integer", "any"],
         swig_fs_set => ["function", "void", "any", "integer"],
+        swig_detected_fs_get => ["function", "integer", "any"],
+        swig_detected_fs_set => ["function", "void", "any", "integer"],
         swig_format_get => ["function", "boolean", "any"],
         swig_format_set => ["function", "void", "any", "boolean"],
         swig_create_get => ["function", "boolean", "any"],
